diff --git a/include/em/em-kernel.h b/include/em/em-kernel.h
index 8a3938fb6..04757499c 100644
--- a/include/em/em-kernel.h
+++ b/include/em/em-kernel.h
@@ -6,10 +6,10 @@
 /*                                                                           */
 /*                                                                           */
 /*                                                                           */
-/* (C) 2002      Ullrich von Bassewitz                                       */
-/*               Wacholderweg 14                                             */
-/*               D-70597 Stuttgart                                           */
-/* EMail:        uz@musoftware.de                                            */
+/* (C) 2002-2003 Ullrich von Bassewitz                                       */
+/*               R�merstrasse 52                                             */
+/*               D-70794 Filderstadt                                         */
+/* EMail:        uz@cc65.org                                                 */
 /*                                                                           */
 /*                                                                           */
 /* This software is provided 'as-is', without any expressed or implied       */
@@ -72,21 +72,6 @@ extern em_drv_header*  	em_drv;       	/* Pointer to driver */
 
 
 
-
-/*****************************************************************************/
-/* 	      	       	      	   Functions	     			     */
-/*****************************************************************************/
-
-
-
-unsigned char __fastcall__ em_install (void* driver);
-/* Install the driver once it is loaded, return an error code. */
-
-void __fastcall__ em_deinstall (void);
-/* Deinstall the driver before unloading it */
-
-
-
 /* End of em-kernel.h */
 #endif
diff --git a/include/em.h b/include/em.h
index 5064d137f..38eb24bb7 100644
--- a/include/em.h
+++ b/include/em.h
@@ -6,10 +6,10 @@
 /*                                                                           */
 /*                                                                           */
 /*                                                                           */
-/* (C) 2002      Ullrich von Bassewitz                                       */
-/*               Wacholderweg 14                                             */
-/*               D-70597 Stuttgart                                           */
-/* EMail:        uz@musoftware.de                                            */
+/* (C) 2002-2003 Ullrich von Bassewitz                                       */
+/*               R�merstrasse 52                                             */
+/*               D-70794 Filderstadt                                         */
+/* EMail:        uz@cc65.org                                                 */
 /*                                                                           */
 /*                                                                           */
 /* This software is provided 'as-is', without any expressed or implied       */
@@ -76,10 +76,18 @@ struct em_copy {
 
 
 unsigned char __fastcall__ em_load_driver (const char* driver);
 /* Load an extended memory driver and return an error code */
 
 unsigned char __fastcall__ em_unload (void);
-/* Unload the currently loaded driver. */
+/* Uninstall, then unload the currently loaded driver. */
+
+unsigned char __fastcall__ em_install (void* driver);
+/* Install an already loaded driver. Return an error code. */
+
+unsigned char __fastcall__ em_uninstall (void);
+/* Uninstall the currently loaded driver and return an error code.
+ * Note: This call does not free allocated memory.
+ */
 
 unsigned __fastcall__ em_pagecount (void);
 /* Return the total number of 256 byte pages available in extended memory. */
@@ -91,7 +99,7 @@ void* __fastcall__ em_map (unsigned page);
  */
 
 void* __fastcall__ em_use (unsigned page);
-/* Tell the driver that the memory window is associated with a given page. 
+/* Tell the driver that the memory window is associated with a given page.
  * This call is very similar to em_map. The difference is that the driver
  * does not necessarily transfer the current contents of the extended
  * memory into the returned window. If you're going to just write to the
@@ -119,7 +127,7 @@ void __fastcall__ em_copyto (const struct em_copy* copy_data);
 
 
 
-/* End of em.h */
+/* End of em.h */               
 #endif
 
 
@@ -76,10 +76,18 @@ struct em_copy {
 
 unsigned char __fastcall__ em_load_driver (const char* driver);
-/* Load an extended memory driver and return an error code */
+/* Load and install an extended memory driver. Return an error code. */
 
 unsigned char __fastcall__ em_unload (void);